Crate cca_rmm

Crate cca_rmm 

Structures and values defined by the Realm Management Monitor

This library provides structure and value definitions from the RMM specification v1.0-rel0. For the moment it only provides the definitions needed for Realm Initial Measurement calculation.

Structs

RmiRealmFlags
Flags provided by the host during Realm creation
RmiRealmParams
RmiRealmParams with only the fields that are measured for the RIM. The rest is set to zero (DEN0137 1.0-rel0 B4.3.9.4 RMI_REALM_CREATE initialization of RIM)
RmiRecCreateFlags
Flags provided by the Host during REC creation
RmiRecParams
RmiRecParams with only the fields that are measured for the RIM. The rest is set to zero (DEN0137 1.0-rel0 B4.3.12.4 RMI_REC_CREATE extension of RIM)
RmmDataFlags
Flags provided by the Host during DATA Granule creation
RmmMeasurementDescriptorData
Structure used to calculate the contribution to the RIM of a data granule
RmmMeasurementDescriptorRec
Structure used to calculate the contribution to the RIM of a REC
RmmMeasurementDescriptorRipas
Structure used to calculate the contribution to the RIM of a RIPAS change

Enums

RmiHashAlgorithm
Hash algorithm used for measurements
RmmError
Error from the RMM library

Constants

RMM_GRANULE
Size of a granule
RMM_REALM_MEASUREMENT_WIDTH
Size of one Realm measurement, in bytes

Type Aliases

RmmRealmMeasurement
One Realm Measurement (initial or extensible)