Structures and values defined by the Realm Management Monitor
This library provides structure and value definitions from the RMM specification v1.0-rel0. For the moment it only provides the definitions needed for Realm Initial Measurement calculation.
Structs
- RmiRealm
Flags - Flags provided by the host during Realm creation
- RmiRealm
Params - RmiRealmParams with only the fields that are measured for the RIM. The rest is set to zero (DEN0137 1.0-rel0 B4.3.9.4 RMI_REALM_CREATE initialization of RIM)
- RmiRec
Create Flags - Flags provided by the Host during REC creation
- RmiRec
Params - RmiRecParams with only the fields that are measured for the RIM. The rest is set to zero (DEN0137 1.0-rel0 B4.3.12.4 RMI_REC_CREATE extension of RIM)
- RmmData
Flags - Flags provided by the Host during DATA Granule creation
- RmmMeasurement
Descriptor Data - Structure used to calculate the contribution to the RIM of a data granule
- RmmMeasurement
Descriptor Rec - Structure used to calculate the contribution to the RIM of a REC
- RmmMeasurement
Descriptor Ripas - Structure used to calculate the contribution to the RIM of a RIPAS change
Enums
- RmiHash
Algorithm - Hash algorithm used for measurements
- RmmError
- Error from the RMM library
Constants
- RMM_
GRANULE - Size of a granule
- RMM_
REALM_ MEASUREMENT_ WIDTH - Size of one Realm measurement, in bytes
Type Aliases
- RmmRealm
Measurement - One Realm Measurement (initial or extensible)